@@ -29,8 +29,9 @@ package stl;
 require 5.005_62;
 use strict;
 use warnings;
-use vars qw( $VERSION $BUILD @EXPORT_OK %EXPORT_TAGS);
-use Exporter;
+use vars qw( $VERSION $BUILD @ISA @EXPORT_OK %EXPORT_TAGS);
+require Exporter;
+@ISA = 'Exporter';
 my @containers = qw(
 	vector list deque queue priority_queue stack tree
 );
